package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;
import java.awt.Image;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.PictureLineSymbol;
import com.esri.arcgis.support.ms.stdole.Picture;
import com.esri.arcgis.display.esriSimpleLineStyle;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads picture line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class PictureLineSymbolReader implements ISymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(SimpleLineSymbolReader.class);

    /**
     * Private member.
     */
    private Element renderer;
    private PictureLineSymbol symbol;
    private MapToXMLUtils util;


    public PictureLineSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof PictureLineSymbol) {
            this.symbol = (PictureLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a PictureLineSymbol!");
        }
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.renderer = parent;
    }

    /**
     * Setter for XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws IOException {
        logger.debug("read()");
        Element symbolElement;
        try {
            symbolElement = util.addSymbol(renderer);
        }
        catch(Exception e) {
            e.printStackTrace();
            return null;
        }

        symbolElement.setAttribute("name", symbol.getNameString());
        symbolElement.setAttribute("style", "picture");
        if(symbol.getColor() instanceof IRgbColor) {
            IRgbColor color = (IRgbColor)symbol.getColor();
            Color c = new Color (
                color.getRed(),
                color.getGreen(),
                color.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
        }
        else {
            RgbColor col = new RgbColor();
            col.setRGB(symbol.getColor().getRGB());
            Color c = new Color (
                col.getRed(),
                col.getGreen(),
                col.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
        }
        symbolElement.setAttribute(
            "offset",
            String.valueOf(symbol.getOffset()));
        symbolElement.setAttribute(
            "x_scale",
            String.valueOf(symbol.getXScale()));
        symbolElement.setAttribute(
            "y_scale",
            String.valueOf(symbol.getYScale()));

        symbolElement.setAttribute("width", String.valueOf(symbol.getWidth()));

        Picture pic = symbol.getPicture();
        Image im = pic.toImage();
        //TODO Save the image.

        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
